﻿using System;
using System.Drawing;
using System.Windows;
using System.Windows.Forms;


namespace RobvanderWoude
{
	class InputBox
	{
		public static TextBox textBox;

		static int Main( string[] args )
		{
			// Based on code by Gorkem Gencay on StackOverflow.com:
			// http://stackoverflow.com/questions/97097/what-is-the-c-sharp-version-of-vb-nets-inputdialog#17546909

			string input;
			string deftitle = "Title";
			string title = deftitle;
			string deftext = "Prompt";
			string text = deftext;
			string defanswer = "Default answer";
			int width = 200;
			int height = 110;

			if ( args.Length > 0 && args.Length < 5 )
			{
				if ( args[0] != "/?" )
				{
					text = args[0];
					title = "© 2014 Rob van der Woude";
					defanswer = String.Empty;
					if ( args.Length > 1 )
					{
						title = args[1];
						if ( args.Length > 2 )
						{
							defanswer = args[2];
							if ( args.Length > 3 )
							{
								try
								{
									width = Convert.ToInt32( args[3] );
									if ( width < 200 || width > Screen.PrimaryScreen.Bounds.Width )
									{
										return WriteError( String.Format( "Invalid screen width: \"{0}\"\n\tWidth must be an integer between 200 and screen width", args[3] ) );
									}
								}
								catch ( FormatException e )
								{
									return WriteError( String.Format( "Invalid width: \"{0}\"\n\t{1}", args[3], e.Message ) );
								}
							}
						}
					}
				}
			}
			else
			{
				return WriteError( );
			}

			Size size = new Size( width, height );
			Form inputBox = new Form( );

			inputBox.FormBorderStyle = FormBorderStyle.FixedDialog;
			inputBox.MaximizeBox = false;
			inputBox.MinimizeBox = false;
			inputBox.StartPosition = FormStartPosition.CenterParent;
			inputBox.ClientSize = size;
			inputBox.Text = title;

			Label labelPrompt = new Label( );
			labelPrompt.Size = new Size( size.Width - 20, 20 );
			labelPrompt.Location = new Point( 10, 10 );
			labelPrompt.Text = text;
			inputBox.Controls.Add( labelPrompt );

			textBox = new TextBox( );
			textBox.Size = new Size( size.Width - 20, 25 );
			textBox.Location = new Point( 10, 35 );
			textBox.Text = defanswer;
			inputBox.Controls.Add( textBox );

			Button okButton = new Button( );
			okButton.DialogResult = DialogResult.OK;
			okButton.Name = "okButton";
			okButton.Size = new Size( 80, 25 );
			okButton.Text = "&OK";
			okButton.Location = new Point( size.Width / 2 - 10 - 80, 70 );
			inputBox.Controls.Add( okButton );

			Button cancelButton = new Button( );
			cancelButton.DialogResult = DialogResult.Cancel;
			cancelButton.Name = "cancelButton";
			cancelButton.Size = new Size( 80, 25 );
			cancelButton.Text = "&Cancel";
			cancelButton.Location = new Point( size.Width / 2 + 10, 70 );
			cancelButton.Click += new EventHandler( cancelButton_Click ); // Delete input text on Cancel
			inputBox.Controls.Add( cancelButton );

			inputBox.AcceptButton = okButton;  // OK on Enter
			inputBox.CancelButton = cancelButton; // Cancel on Esc
			inputBox.Activate( );

			DialogResult result = inputBox.ShowDialog( );
			if ( result == DialogResult.OK )
			{
				input = textBox.Text;
				if ( args.Length > 0 && args[0] == "/?" )
				{
					Console.Error.Write( "\nYou entered: \"" );
					Console.Write( input );
					Console.Error.WriteLine( "\"\n\n" );
					return WriteError( );
				}
				else
				{
					Console.WriteLine( input );
					return 0;
				}
			}
			else
			{
				if ( args.Length > 0 && args[0] == "/?" )
				{
					return WriteError( );
				}
				else
				{
					return 2;
				}
			}
		}


		// Delete entered text if Cancel button is clicked (or Esc key pressed)
		public static void cancelButton_Click( object sender, EventArgs e )
		{
			textBox.Text.Remove( 0 );
		}


		public static int WriteError( string errorMessage = null )
		{
			/*
			InputBox,  Version 1.01
			Prompt for input (GUI)

			Usage:    INPUTBOX  "prompt"  [ "title"  [ "default"  [ width ] ] ]

			Where:    "prompt"   is the text above the input field
			          "title"    is the optional caption in the title bar
			          "default"  is the optional default answer shown in the input field
			          width      is the optional width of the input box
			                     (default: 200; minimum: 200; maximum: screen width)

			Notes:    Text from input field is written to Standard Out if "OK" is clicked.
			          Return code 0 for \"OK\", 1 for (command line) errors, 2 for \"Cancel\".

			Credits:  Based on code by Gorkem Gencay on StackOverflow:
			          http://stackoverflow.com/questions/97097
			          /what-is-the-c-sharp-version-of-vb-nets-inputdialog#17546909

			Written by Rob van der Woude
			http://www.robvanderwoude.com
			*/

			if ( string.IsNullOrEmpty( errorMessage ) == false )
			{
				Console.Error.WriteLine( );
				Console.ForegroundColor = ConsoleColor.Red;
				Console.Error.Write( "ERROR:\t" );
				Console.ForegroundColor = ConsoleColor.White;
				Console.Error.WriteLine( errorMessage );
				Console.ResetColor( );
			}

			Console.Error.WriteLine( );
			Console.Error.WriteLine( "InputBox,  Version 1.01" );
			Console.Error.WriteLine( "Prompt for input (GUI)" );
			Console.Error.WriteLine( );
			Console.Error.Write( "Usage:    " );
			Console.ForegroundColor = ConsoleColor.White;
			Console.Error.WriteLine( "INPUTBOX  \"prompt\"  [ \"title\"  [ \"default\"  [ width ] ] ]" );
			Console.ResetColor( );
			Console.Error.WriteLine( );
			Console.Error.Write( "Where:    " );
			Console.ForegroundColor = ConsoleColor.White;
			Console.Error.Write( "\"prompt\"" );
			Console.ResetColor( );
			Console.Error.WriteLine( "   is the text above the input field" );
			Console.ForegroundColor = ConsoleColor.White;
			Console.Error.Write( "          \"title\"" );
			Console.ResetColor( );
			Console.Error.WriteLine( "    is the optional caption in the title bar" );
			Console.ForegroundColor = ConsoleColor.White;
			Console.Error.Write( "          \"default\"" );
			Console.ResetColor( );
			Console.Error.WriteLine( "  is the optional default answer shown in the input field" );
			Console.ForegroundColor = ConsoleColor.White;
			Console.Error.Write( "          width" );
			Console.ResetColor( );
			Console.Error.WriteLine( "      is the optional width of the input box" );
			Console.Error.WriteLine( "                     (default: 200; minimum: 200; maximum: screen width)" );
			Console.Error.WriteLine( );
			Console.Error.WriteLine( "Notes:    Text from input field is written to Standard Output if \"OK\" is clicked." );
			Console.Error.WriteLine( "          Return code 0 for \"OK\", 1 for (command line) errors, 2 for \"Cancel\"." );
			Console.Error.WriteLine( );
			Console.Error.WriteLine( "Credits:  Based on code by Gorkem Gencay on StackOverflow:" );
			Console.ForegroundColor = ConsoleColor.DarkGray;
			Console.Error.WriteLine( "          http://stackoverflow.com/questions/97097" );
			Console.Error.WriteLine( "          /what-is-the-c-sharp-version-of-vb-nets-inputdialog#17546909" );
			Console.ResetColor( );
			Console.Error.WriteLine( );
			Console.Error.WriteLine( "Written by Rob van der Woude" );
			Console.Error.WriteLine( "http://www.robvanderwoude.com" );
			return 1;
		}
	}
}
